==> jc-1.4.0.tar.gz: java/net/PasswordAuthentication.c <==
// public final class java.net.PasswordAuthentication

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class dad0c2390a9d10f2 java_net_PasswordAuthentication

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_net_PasswordAuthentication

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/net/PasswordAuthentication.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String username
static _jc_field _jc_java_net_PasswordAuthentication$field_info$username = {
	.name=		"username",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_net_PasswordAuthentication$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_net_PasswordAuthentication$object, refs[-1].java_net_PasswordAuthentication.username),
};

// private char[] password
static _jc_field _jc_java_net_PasswordAuthentication$field_info$password = {
	.name=		"password",
	.signature=	"[C",
	.class=		&_jc_java_net_PasswordAuthentication$type,
	.type=		&_jc_char$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_net_PasswordAuthentication$object, refs[-1].java_net_PasswordAuthentication.password),
};

// Fields
static _jc_field *const _jc_java_net_PasswordAuthentication$fields[] = {
	&_jc_java_net_PasswordAuthentication$field_info$password,
	&_jc_java_net_PasswordAuthentication$field_info$username
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, char[])
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$_init$c43892a3c8ac5541[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$_init$c43892a3c8ac5541[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_net_PasswordAuthentication$param_types$_init$c43892a3c8ac5541[] = {
	&_jc_java_lang_String$type,
	&_jc_char$array$prim$type
};

_jc_method _jc_java_net_PasswordAuthentication$method_info$_init$c43892a3c8ac5541 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;[C)V",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.param_types=		&_jc_java_net_PasswordAuthentication$param_types$_init$c43892a3c8ac5541,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$_init$c43892a3c8ac5541,
	.signature_hash=	_JC_JLONG(0xc43892a3c8ac5541),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$_init$c43892a3c8ac5541
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, _init$c43892a3c8ac5541);

void
_jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this, _jc_java_lang_String$object *param0, _jc_char_array *param1)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	struct _jc_java_lang_String$object *r1;
	_jc_char_array *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(69);				// 0
	_JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, username) = r1;
	_JC_LINE_NUMBER(70);				// 1
	_JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, password) = r2;
	_JC_LINE_NUMBER(71);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final char[] getPassword()
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$getPassword$6adf0c63e283126f[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$getPassword$6adf0c63e283126f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f = {
	.name=			"getPassword",
	.signature=		"()[C",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.return_type=		&_jc_char$array$prim$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$getPassword$6adf0c63e283126f,
	.signature_hash=	_JC_JLONG(0x6adf0c63e283126f),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_PasswordAuthentication$vtable, java_net_PasswordAuthentication.getPassword$6adf0c63e283126f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$getPassword$6adf0c63e283126f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, getPassword$6adf0c63e283126f);

_jc_char_array *
_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	_jc_char_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(90);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, password);
	return r1;
}

//
// public final java.lang.String getUserName()
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$getUserName$ccf38f85d7c727d5[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$getUserName$ccf38f85d7c727d5[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5 = {
	.name=			"getUserName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$getUserName$ccf38f85d7c727d5,
	.signature_hash=	_JC_JLONG(0xccf38f85d7c727d5),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_PasswordAuthentication$vtable, java_net_PasswordAuthentication.getUserName$ccf38f85d7c727d5) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$getUserName$ccf38f85d7c727d5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, getUserName$ccf38f85d7c727d5);

_jc_java_lang_String$object *
_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(80);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, username);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_PasswordAuthentication$methods[] = {
	&_jc_java_net_PasswordAuthentication$method_info$_init$c43892a3c8ac5541,
	&_jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f,
	&_jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_PasswordAuthentication$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_PasswordAuthentication$instanceof_hash_bucket_114[] = {
	&_jc_java_net_PasswordAuthentication$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_PasswordAuthentication$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[113]=	_jc_java_net_PasswordAuthentication$instanceof_hash_bucket_113,
	[114]=	_jc_java_net_PasswordAuthentication$instanceof_hash_bucket_114
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_PasswordAuthentication$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_PasswordAuthentication$vtype _jc_java_net_PasswordAuthentication$type = {
    .type= {
	.name=			"java/net/PasswordAuthentication",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xdad0c2390a9d10f2),
		.source_file=		"PasswordAuthentication.java",
		.instance_size=		sizeof(_jc_java_net_PasswordAuthentication$refs) + sizeof(_jc_java_net_PasswordAuthentication$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_java_net_PasswordAuthentication$fields) / sizeof(*_jc_java_net_PasswordAuthentication$fields),
		.fields=		_jc_java_net_PasswordAuthentication$fields,
		.num_methods=		sizeof(_jc_java_net_PasswordAuthentication$methods) / sizeof(*_jc_java_net_PasswordAuthentication$methods),
		.methods=		_jc_java_net_PasswordAuthentication$methods,
		.instanceof_hash_table=	_jc_java_net_PasswordAuthentication$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_PasswordAuthentication$class_depends) / sizeof(*_jc_java_net_PasswordAuthentication$class_depends),
		.class_depends=		_jc_java_net_PasswordAuthentication$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_PasswordAuthentication= {
	    .getPassword$6adf0c63e283126f=
		&_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f,
	    .getUserName$ccf38f85d7c727d5=
		&_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5,
	},
    }
};

==> jc-1.4.5.tar.gz: java/net/PasswordAuthentication.c <==
// public final class java.net.PasswordAuthentication

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class dad0c2390a9d10f2 java_net_PasswordAuthentication

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_net_PasswordAuthentication

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/net/PasswordAuthentication.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.String username
static _jc_field _jc_java_net_PasswordAuthentication$field_info$username = {
	.name=		"username",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_net_PasswordAuthentication$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_net_PasswordAuthentication$object, refs[-1].java_net_PasswordAuthentication.username),
};

// private char[] password
static _jc_field _jc_java_net_PasswordAuthentication$field_info$password = {
	.name=		"password",
	.signature=	"[C",
	.class=		&_jc_java_net_PasswordAuthentication$type,
	.type=		&_jc_char$array$prim$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_net_PasswordAuthentication$object, refs[-1].java_net_PasswordAuthentication.password),
};

// Fields
static _jc_field *const _jc_java_net_PasswordAuthentication$fields[] = {
	&_jc_java_net_PasswordAuthentication$field_info$password,
	&_jc_java_net_PasswordAuthentication$field_info$username
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, char[])
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$_init$c43892a3c8ac5541[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$_init$c43892a3c8ac5541[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_net_PasswordAuthentication$param_types$_init$c43892a3c8ac5541[] = {
	&_jc_java_lang_String$type,
	&_jc_char$array$prim$type
};

_jc_method _jc_java_net_PasswordAuthentication$method_info$_init$c43892a3c8ac5541 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;[C)V",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.param_types=		&_jc_java_net_PasswordAuthentication$param_types$_init$c43892a3c8ac5541,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$_init$c43892a3c8ac5541,
	.signature_hash=	_JC_JLONG(0xc43892a3c8ac5541),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$_init$c43892a3c8ac5541
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, _init$c43892a3c8ac5541);

void _JC_JCNI_ATTR
_jc_java_net_PasswordAuthentication$method$_init$c43892a3c8ac5541(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this, _jc_java_lang_String$object *param0, _jc_char_array *param1)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	struct _jc_java_lang_String$object *r1;
	_jc_char_array *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(69);				// 0
	_JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, username) = r1;
	_JC_LINE_NUMBER(70);				// 1
	_JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, password) = r2;
	_JC_LINE_NUMBER(71);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final char[] getPassword()
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$getPassword$6adf0c63e283126f[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$getPassword$6adf0c63e283126f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f = {
	.name=			"getPassword",
	.signature=		"()[C",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.return_type=		&_jc_char$array$prim$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$getPassword$6adf0c63e283126f,
	.signature_hash=	_JC_JLONG(0x6adf0c63e283126f),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_PasswordAuthentication$vtable, java_net_PasswordAuthentication.getPassword$6adf0c63e283126f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$getPassword$6adf0c63e283126f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, getPassword$6adf0c63e283126f);

_jc_char_array * _JC_JCNI_ATTR
_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	_jc_char_array *r1;

	r0 = this;
	_JC_LINE_NUMBER(90);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, password);
	return r1;
}

//
// public final java.lang.String getUserName()
//

static _jc_linenum _jc_java_net_PasswordAuthentication$linenum_table$getUserName$ccf38f85d7c727d5[];

static const unsigned char _jc_java_net_PasswordAuthentication$param_ptypes$getUserName$ccf38f85d7c727d5[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5 = {
	.name=			"getUserName",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_net_PasswordAuthentication$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_net_PasswordAuthentication$param_ptypes$getUserName$ccf38f85d7c727d5,
	.signature_hash=	_JC_JLONG(0xccf38f85d7c727d5),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_PasswordAuthentication$vtable, java_net_PasswordAuthentication.getUserName$ccf38f85d7c727d5) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_PasswordAuthentication$linenum_table$getUserName$ccf38f85d7c727d5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_PasswordAuthentication, getUserName$ccf38f85d7c727d5);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5(_jc_env *const env, _jc_java_net_PasswordAuthentication$object *this)
{
	struct _jc_java_net_PasswordAuthentication$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(80);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_net_PasswordAuthentication, username);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_PasswordAuthentication$methods[] = {
	&_jc_java_net_PasswordAuthentication$method_info$_init$c43892a3c8ac5541,
	&_jc_java_net_PasswordAuthentication$method_info$getPassword$6adf0c63e283126f,
	&_jc_java_net_PasswordAuthentication$method_info$getUserName$ccf38f85d7c727d5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_PasswordAuthentication$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_PasswordAuthentication$instanceof_hash_bucket_114[] = {
	&_jc_java_net_PasswordAuthentication$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_PasswordAuthentication$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_java_net_PasswordAuthentication$instanceof_hash_bucket_101,
	[114]=	_jc_java_net_PasswordAuthentication$instanceof_hash_bucket_114
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_PasswordAuthentication$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_PasswordAuthentication$vtype _jc_java_net_PasswordAuthentication$type = {
    .type= {
	.name=			"java/net/PasswordAuthentication",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xdad0c2390a9d10f2),
		.source_file=		"PasswordAuthentication.java",
		.instance_size=		sizeof(_jc_java_net_PasswordAuthentication$refs) + sizeof(_jc_java_net_PasswordAuthentication$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_java_net_PasswordAuthentication$fields) / sizeof(*_jc_java_net_PasswordAuthentication$fields),
		.fields=		_jc_java_net_PasswordAuthentication$fields,
		.num_methods=		sizeof(_jc_java_net_PasswordAuthentication$methods) / sizeof(*_jc_java_net_PasswordAuthentication$methods),
		.methods=		_jc_java_net_PasswordAuthentication$methods,
		.instanceof_hash_table=	_jc_java_net_PasswordAuthentication$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_PasswordAuthentication$class_depends) / sizeof(*_jc_java_net_PasswordAuthentication$class_depends),
		.class_depends=		_jc_java_net_PasswordAuthentication$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_PasswordAuthentication= {
	    .getPassword$6adf0c63e283126f=
		&_jc_java_net_PasswordAuthentication$method$getPassword$6adf0c63e283126f,
	    .getUserName$ccf38f85d7c727d5=
		&_jc_java_net_PasswordAuthentication$method$getUserName$ccf38f85d7c727d5,
	},
    }
};
